==> qmmp-plugin-pack-0.12.2.tar.bz2: qmmp-plugin-pack-0.12.2/src/Visual/goom/translations/goom_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>GoomWidget</name>
    <message>
        <location filename="../goomwidget.cpp" line="137"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="187"/>
        <source>Refresh Rate</source>
        <translation>リフレッシュレート</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="190"/>
        <source>60 fps</source>
        <translation>60 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="191"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="192"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="198"/>
        <source>&amp;Show Title</source>
        <translation>タイトル表示(&amp;S)</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>&amp;Full Screen</source>
        <translation>全画面表示(&amp;F)</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualGoomFactory</name>
    <message>
        <location filename="../visualgoomfactory.cpp" line="30"/>
        <source>Goom</source>
        <translation>Goom</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="49"/>
        <source>About Goom Visual Plugin</source>
        <translation>Goom 視覚効果プラグインについて</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="50"/>
        <source>Qmmp Goom Visual Plugin</source>
        <translation>QMMP Goom 視覚効果プラグイン</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="52"/>
        <source>Based on the source code from the Goom project</source>
        <translation>Goom project のソースコードを基に作成</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="53"/>
        <source>Goom project developers:</source>
        <translation>Goom project 開発者:</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="54"/>
        <source>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</source>
        <translation>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="55"/>
        <source>Guillaume Borios &lt;gyom@ios-software.com&gt;</source>
        <translation>Guillaume Borios &lt;gyom@ios-software.com&gt;</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-2.2.2.tar.bz2: qmmp-plugin-pack-2.2.2/src/Visual/goom/translations/goom_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>GoomWidget</name>
    <message>
        <location filename="../goomwidget.cpp" line="137"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="187"/>
        <source>Refresh Rate</source>
        <translation>再描画の頻度</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="190"/>
        <source>60 fps</source>
        <translation>60 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="191"/>
        <source>50 fps</source>
        <translation>50 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="192"/>
        <source>25 fps</source>
        <translation>25 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="198"/>
        <source>&amp;Show Title</source>
        <translation>タイトル表示(&amp;S)</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="202"/>
        <location filename="../goomwidget.cpp" line="204"/>
        <source>&amp;Full Screen</source>
        <translation>フルスクリーン(&amp;F)</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="202"/>
        <location filename="../goomwidget.cpp" line="204"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualGoomFactory</name>
    <message>
        <location filename="../visualgoomfactory.cpp" line="30"/>
        <source>Goom</source>
        <translation>Goom</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="49"/>
        <source>About Goom Visual Plugin</source>
        <translation>Goom 視覚効果プラグインについて</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="50"/>
        <source>Qmmp Goom Visual Plugin</source>
        <translation>QMMP Goom 視覚効果プラグイン</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="52"/>
        <source>Based on the source code from the Goom project</source>
        <translation>Goom project のソースコードを基に作成</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="53"/>
        <source>Goom project developers:</source>
        <translation>Goom project 開発者:</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="54"/>
        <source>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</source>
        <translation>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="55"/>
        <source>Guillaume Borios &lt;gyom@ios-software.com&gt;</source>
        <translation>Guillaume Borios &lt;gyom@ios-software.com&gt;</translation>
    </message>
</context>
</TS>
